import {
  transformJSX
} from "./chunk-7JJPREQH.js";
import {
  isConditionalExpression,
  isJSXElement
} from "./chunk-U5SL6DPK.js";

// src/index.ts
import { parse } from "@babel/parser";
import _SyntaxJSX from "@babel/plugin-syntax-jsx";
var SyntaxJSX = _SyntaxJSX.default || _SyntaxJSX;
var index_default = () => {
  return {
    name: "Vue JSX Vapor",
    inherits: SyntaxJSX,
    visitor: {
      JSXElement: transformJSX,
      JSXFragment: transformJSX,
      Program: {
        enter: (path, state) => {
          state.importSet = /* @__PURE__ */ new Set();
          state.delegateEventSet = /* @__PURE__ */ new Set();
          state.preambleMap = /* @__PURE__ */ new Map();
          state.preambleIndex = 0;
          state.roots = [];
          const collectRoot = (path2) => {
            if (!isJSXElement(path2.parent) && !isConditionalExpression(path2.parentPath)) {
              state.roots.push({
                node: path2.node,
                source: path2.getSource(),
                inVaporComponent: !state.opts.interop ? true : path2.findParent(
                  ({ node }) => node.type === "CallExpression" && node.callee.type === "Identifier" && ["defineVaporComponent", "defineComponent"].includes(
                    node.callee.name
                  )
                )?.node.callee.name === "defineVaporComponent"
              });
            }
          };
          path.traverse({
            JSXElement: collectRoot,
            JSXFragment: collectRoot
          });
        },
        exit: (path, state) => {
          const { delegateEventSet, importSet, preambleMap } = state;
          const statements = [];
          if (delegateEventSet.size) {
            statements.unshift(
              `_delegateEvents(${Array.from(delegateEventSet).join(", ")});`
            );
          }
          if (preambleMap.size) {
            let preambleResult = "";
            for (const [value, key] of preambleMap) {
              preambleResult += `const ${key} = ${value}
`;
            }
            statements.unshift(preambleResult);
          }
          const helpers = ["setNodes", "createNodes"].filter((helper) => {
            const result = importSet.has(helper);
            result && importSet.delete(helper);
            return result;
          });
          if (helpers.length) {
            statements.unshift(
              `import { ${helpers.map((i) => `${i} as _${i}`).join(", ")} } from 'vue-jsx-vapor/runtime';
`
            );
          }
          if (importSet.size) {
            const importResult = Array.from(importSet).map((i) => `${i} as _${i}`).join(", ");
            statements.unshift(`import { ${importResult} } from 'vue';
`);
          }
          path.node.body.unshift(
            ...parse(statements.join("\n"), { sourceType: "module" }).program.body
          );
        }
      }
    }
  };
};
export {
  index_default as default
};
